@@ -1,11 +1,11 @@
-from typing import Dict, Any
+from typing import Dict, Any, List
 
 from pyspark.sql import SparkSession, DataFrame
 from pyspark.sql.types import StructType
 
 
 def create_view_from_dictionary(view: str,
-                                data: [Dict[str, Any]],
+                                data: List[Dict[str, Any]],
                                 spark_session: SparkSession,
                                 schema=None
                                 ) -> DataFrame:
